@@ -2,11 +2,11 @@ from __future__ import division, absolute_import, print_function, unicode_litera
 
 import awlsim.cython_helper as __cython
 
-if __cython.shouldUseCython():						#@nocy
+if __cython.shouldUseCython(__name__):					#@nocy
 #if True:								#@cy
 	try:
 		from awlsim_cython.coreclient.all_modules import *	#<no-cython-patch
 	except ImportError as e:
-		__cython.cythonImportError("coreclient", str(e))
-if not __cython.shouldUseCython():					#@nocy
+		__cython.cythonImportError(__name__, str(e))
+if not __cython.shouldUseCython(__name__):				#@nocy
 	from awlsim.coreclient.all_modules import *			#@nocy
