@@ -24,15 +24,9 @@ from awlsim.common.compat import *
 
 from awlsim.gui.util import *
 from awlsim.gui.cpuwidget import *
+from awlsim.gui.sourcecodeedit import *
 
 
-def _setFontParams(font):
-	font.setFamily("courier")
-	font.setPointSize(10)
-	font.setKerning(False)
-	font.setFixedPitch(True)
-	font.setStyleHint(QFont.TypeWriter, QFont.PreferBitmap)
-
 class EditSubWidget(QWidget):
 	needRepaint = Signal(QPaintEvent)
 	wasScrolled = Signal(QWheelEvent)
@@ -52,7 +46,7 @@ class EditSubWidget(QWidget):
 	def getPainter(self):
 		p = QPainter(self)
 		font = p.font()
-		_setFontParams(font)
+		setFixedFontParams(font)
 		p.setFont(font)
 		return p
 
@@ -340,15 +334,14 @@ class CpuStatsContextMenu(QMenu):
 	def __actionToggled(self, newState):
 		self.closed.emit()
 
-class EditWidget(QPlainTextEdit):
+class EditWidget(SourceCodeEdit):
 	codeChanged = Signal()
 	visibleRangeChanged = Signal()
 
 	__aniChars = ( ' ', '.', 'o', '0', 'O', '0', 'o', '.' )
 
-	def __init__(self, mainWidget):
-		QPlainTextEdit.__init__(self, mainWidget)
-		self.mainWidget = mainWidget
+	def __init__(self, parent=None):
+		SourceCodeEdit.__init__(self, parent)
 
 		self.__aniTimer = QTimer(self)
 		self.__aniTimer.setSingleShot(False)
@@ -358,7 +351,7 @@ class EditWidget(QPlainTextEdit):
 
 		self.setHorizontalScrollBarPolicy(Qt.ScrollBarAsNeeded)
 		self.setVerticalScrollBarPolicy(Qt.ScrollBarAsNeeded)
-		self.setLineWrapMode(QPlainTextEdit.NoWrap)
+		self.setLineWrapMode(SourceCodeEdit.NoWrap)
 		self.setTabStopWidth(self.tabStopWidth() // 2)
 
 		self.headerWidget = HeaderSubWidget(self)
@@ -479,11 +472,11 @@ class EditWidget(QPlainTextEdit):
 	def __updateFonts(self):
 		fmt = self.currentCharFormat()
 		font = fmt.font()
-		_setFontParams(font)
+		setFixedFontParams(font)
 		fmt.setFont(font)
 		self.setCurrentCharFormat(fmt)
 		font = self.font()
-		_setFontParams(font)
+		setFixedFontParams(font)
 		self.setFont(font)
 		self.__charHeight = self.fontMetrics().height()
 		self.setTabStopWidth(self.fontMetrics().width("X") * 8)
@@ -546,6 +539,8 @@ class EditWidget(QPlainTextEdit):
 			self.__cpuStatsStamp += 1
 
 	def __pruneInvisibleCpuStats(self):
+		if self.__runStateCopy == CpuWidget.STATE_STOP:
+			return
 		firstLine, lastLine = self.getVisibleLineRange()
 		for line, stats in self.__lineCpuStats.items():
 			if line < firstLine or line > lastLine:
@@ -584,7 +579,7 @@ class EditWidget(QPlainTextEdit):
 					0)
 
 	def sizeHint(self):
-		sh = QPlainTextEdit.sizeHint(self)
+		sh = SourceCodeEdit.sizeHint(self)
 		sh.setWidth(650 +\
 			    self.lineNumWidgetWidth() +\
 			    self.cpuStatsWidgetWidth())
@@ -644,13 +639,14 @@ class EditWidget(QPlainTextEdit):
 			self.__updateMargins()
 
 	def resizeEvent(self, ev):
-		QPlainTextEdit.resizeEvent(self, ev)
+		SourceCodeEdit.resizeEvent(self, ev)
 		self.__updateGeo()
 
 	__runStateToText = {
-		CpuWidget.STATE_STOP	: "-- CPU STOPPED --",
-		CpuWidget.STATE_INIT	: "Initializing simulator...",
-		CpuWidget.STATE_LOAD	: "Loading code...",
+		CpuWidget.STATE_STOP		: "-- CPU STOPPED --",
+		CpuWidget.STATE_INIT		: "Initializing simulator...",
+		CpuWidget.STATE_LOAD		: "Loading code...",
+		CpuWidget.STATE_EXCEPTION	: "ERROR. CPU halted.",
 	}
 
 	def __repaintHeaderWidget(self, ev):
