@@ -59,6 +59,7 @@ class MainWidget(QWidget):
 
 		self.projectWidget.codeChanged.connect(self.__somethingChanged)
 		self.projectWidget.symTabChanged.connect(self.__somethingChanged)
+		self.projectWidget.libTableChanged.connect(self.__somethingChanged)
 		self.projectWidget.visibleLinesChanged.connect(self.cpuWidget.updateVisibleLineRange)
 		self.cpuWidget.runStateChanged.connect(self.__runStateChanged)
 		self.cpuWidget.onlineDiagChanged.connect(self.projectWidget.handleOnlineDiagChange)
@@ -225,6 +226,9 @@ class MainWidget(QWidget):
 	def insertFBcall(self):
 		self.projectWidget.insertFBcall()
 
+	def openLibrary(self):
+		self.projectWidget.openLibrary()
+
 class MainWindow(QMainWindow):
 	@classmethod
 	def start(cls,
@@ -252,24 +256,26 @@ class MainWindow(QMainWindow):
 		menu.addAction("&Exit...", self.close)
 		self.menuBar().addMenu(menu)
 
-		menu = QMenu("&Templates", self)
-		menu.addAction("Insert &OB...", self.insertOB)
-		menu.addAction("Insert F&C...", self.insertFC)
-		menu.addAction("Insert F&B...", self.insertFB)
-		menu.addAction("Insert &instance-DB...", self.insertInstanceDB)
-		menu.addAction("Insert &DB...", self.insertGlobalDB)
-		menu.addAction("Insert &UDT...", self.insertUDT)
+		menu = QMenu("&Library", self)
+		menu.addAction(getIcon("textsource"), "Insert &OB template...", self.insertOB)
+		menu.addAction(getIcon("textsource"), "Insert F&C template...", self.insertFC)
+		menu.addAction(getIcon("textsource"), "Insert F&B template...", self.insertFB)
+		menu.addAction(getIcon("textsource"), "Insert &instance-DB template...", self.insertInstanceDB)
+		menu.addAction(getIcon("textsource"), "Insert &DB template...", self.insertGlobalDB)
+		menu.addAction(getIcon("textsource"), "Insert &UDT template...", self.insertUDT)
 		menu.addSeparator()
-		menu.addAction("Insert FC C&ALL...", self.insertFCcall)
-		menu.addAction("Insert FB CA&LL...", self.insertFBcall)
+		menu.addAction(getIcon("textsource"), "Insert FC C&ALL template...", self.insertFCcall)
+		menu.addAction(getIcon("textsource"), "Insert FB CA&LL template...", self.insertFBcall)
+		menu.addSeparator()
+		menu.addAction(getIcon("stdlib"), "&Standard library...", self.openLibrary)
 		self.menuBar().addMenu(menu)
 
 		menu = QMenu("&PLC", self)
-		menu.addAction("&Server connection...", self.coreConfig)
-		menu.addAction("&CPU config...", self.cpuConfig)
+		menu.addAction(getIcon("network"), "&Server connection...", self.coreConfig)
+		menu.addAction(getIcon("prefs"), "&CPU config...", self.cpuConfig)
 		self.menuBar().addMenu(menu)
 
-		menu = QMenu("Help", self)
+		menu = QMenu("&Help", self)
 		menu.addAction(getIcon("cpu"), "&About...", self.about)
 		self.menuBar().addMenu(menu)
 
@@ -277,6 +283,8 @@ class MainWindow(QMainWindow):
 		self.tb.addAction(getIcon("new"), "New project", self.new)
 		self.tb.addAction(getIcon("open"), "Open project", self.load)
 		self.tbSaveAct = self.tb.addAction(getIcon("save"), "Save project", self.save)
+		self.tb.addSeparator()
+		self.tb.addAction(getIcon("stdlib"), "Standard library", self.openLibrary)
 		self.addToolBar(self.tb)
 
 		self.__dirtyChanged(False)
@@ -338,7 +346,7 @@ class MainWindow(QMainWindow):
 				postfix += "*"
 		else:
 			postfix = ""
-		self.setWindowTitle("AWL/STL Soft-PLC v%d.%d%s" %\
+		self.setWindowTitle("AWL/STL soft-PLC v%d.%d%s" %\
 				    (VERSION_MAJOR, VERSION_MINOR,
 				     postfix))
 
@@ -373,12 +381,27 @@ class MainWindow(QMainWindow):
 		QMainWindow.closeEvent(self, ev)
 
 	def about(self):
-		QMessageBox.about(self, "About AWL/STL Soft-PLC",
-			"awlsim version %d.%d\n\n"
+		QMessageBox.about(self, "About AWL/STL soft-PLC",
+			"Awlsim soft-PLC version %d.%d\n"
+			"\n"
 			"Copyright 2012-2014 Michael Büsch <m@bues.ch>\n"
-			"Licensed under the terms of the "
-			"GNU GPL version 2 or (at your option) "
-			"any later version." %\
+			"\n"
+			"Project home:  http://bues.ch/h/awlsim\n"
+			"\n"
+			"\n"
+			"This program is free software; you can redistribute it and/or modify "
+			"it under the terms of the GNU General Public License as published by "
+			"the Free Software Foundation; either version 2 of the License, or "
+			"(at your option) any later version.\n"
+			"\n"
+			"This program is distributed in the hope that it will be useful, "
+			"but WITHOUT ANY WARRANTY; without even the implied warranty of "
+			"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the "
+			"GNU General Public License for more details.\n"
+			"\n"
+			"You should have received a copy of the GNU General Public License along "
+			"with this program; if not, write to the Free Software Foundation, Inc., "
+			"51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA." %\
 			(VERSION_MAJOR, VERSION_MINOR))
 
 	def new(self):
@@ -399,6 +422,9 @@ class MainWindow(QMainWindow):
 	def coreConfig(self):
 		self.centralWidget().coreConfig()
 
+	def openLibrary(self):
+		self.centralWidget().openLibrary()
+
 # If invoked as script, run a new instance.
 if __name__ == "__main__":
 	fn = sys.argv[1] if (len(sys.argv) >= 2) else None
