@@ -26,6 +26,9 @@ from awlsim.common.templates import *
 
 from awlsim.gui.util import *
 from awlsim.gui.sourcetabs import *
+from awlsim.gui.library import *
+from awlsim.gui.libtablewidget import *
+from awlsim.gui.icons import *
 
 
 class TemplateDialog(QDialog):
@@ -38,34 +41,38 @@ class TemplateDialog(QDialog):
 
 		self.setWindowTitle("Insert %s template" % verboseBlockName)
 
+		label = QLabel(self)
+		label.setPixmap(getIcon("textsource").pixmap(QSize(48, 48)))
+		self.layout().addWidget(label, 0, 0)
+
 		label = QLabel("Insert %s template." % verboseBlockName, self)
-		self.layout().addWidget(label, 0, 0, 1, 2)
+		self.layout().addWidget(label, 1, 0, 1, 2)
 
 		label = QLabel("%s number:" % verboseBlockName, self)
-		self.layout().addWidget(label, 1, 0)
+		self.layout().addWidget(label, 2, 0)
 		self.blockNr = QSpinBox(self)
 		self.blockNr.setMinimum(1)
 		self.blockNr.setMaximum(0xFFFF)
 		self.blockNr.setValue(1)
 		self.blockNr.setPrefix(blockName + " ")
-		self.layout().addWidget(self.blockNr, 1, 1)
+		self.layout().addWidget(self.blockNr, 2, 1)
 
 		if extra:
 			label = QLabel("%s number:" % extra, self)
-			self.layout().addWidget(label, 2, 0)
+			self.layout().addWidget(label, 3, 0)
 			self.extraNr = QSpinBox(self)
 			self.extraNr.setMinimum(1)
 			self.extraNr.setMaximum(0xFFFF)
 			self.extraNr.setValue(1)
 			self.extraNr.setPrefix(extra + " ")
-			self.layout().addWidget(self.extraNr, 2, 1)
+			self.layout().addWidget(self.extraNr, 3, 1)
 
 		self.verbose = QCheckBox("Generate verbose code", self)
 		self.verbose.setCheckState(Qt.Checked)
-		self.layout().addWidget(self.verbose, 3, 0, 1, 2)
+		self.layout().addWidget(self.verbose, 4, 0, 1, 2)
 
 		self.okButton = QPushButton("&Paste code", self)
-		self.layout().addWidget(self.okButton, 4, 0, 1, 2)
+		self.layout().addWidget(self.okButton, 5, 0, 1, 2)
 
 		self.okButton.released.connect(self.accept)
 
@@ -86,23 +93,29 @@ class ProjectWidget(QTabWidget):
 	# Signal: The visible AWL line range changed
 	#         Parameters are: source, visibleFromLine, visibleToLine
 	visibleLinesChanged = Signal(AwlSource, int, int)
+	# Signal: The library selection changed
+	libTableChanged = Signal()
 
 	def __init__(self, parent=None):
 		QTabWidget.__init__(self, parent)
 
 		self.awlTabs = AwlSourceTabWidget(self)
 		self.symTabs = SymSourceTabWidget(self)
+		self.libTable = LibTableView(None, self)
 
 		self.addTab(self.awlTabs, "Sources")
 		self.addTab(self.symTabs, "Symbol tables")
+		self.addTab(self.libTable, "Library selections")
 		self.setTabToolTip(0, "Enter your AWL/STL program here")
 		self.setTabToolTip(1, "Enter your symbol table here")
+		self.setTabToolTip(2, "Select standard libraries to include")
 
 		self.reset()
 
 		self.awlTabs.sourceChanged.connect(self.codeChanged)
-		self.symTabs.sourceChanged.connect(self.symTabChanged)
 		self.awlTabs.visibleLinesChanged.connect(self.visibleLinesChanged)
+		self.symTabs.sourceChanged.connect(self.symTabChanged)
+		self.libTable.model().contentChanged.connect(self.libTableChanged)
 
 	def handleOnlineDiagChange(self, enabled):
 		self.awlTabs.handleOnlineDiagChange(enabled)
@@ -127,6 +140,10 @@ class ProjectWidget(QTabWidget):
 		"Returns a list of SymTabSource()s"
 		return self.symTabs.getSources()
 
+	def getLibSelections(self):
+		"Returns a list of AwlLibEntrySelection()s"
+		return self.libTable.model().getLibSelections()
+
 	def reset(self):
 		self.__project = Project(None) # Empty project
 		self.__isAdHocProject = False
@@ -138,6 +155,7 @@ class ProjectWidget(QTabWidget):
 		self.__project = project
 		self.awlTabs.setSources(self.__project.getAwlSources())
 		self.symTabs.setSources(self.__project.getSymTabSources())
+		self.libTable.model().setLibSelections(self.__project.getLibSelections())
 		self.__warnedFileBacked = False
 
 	def __loadPlainAwlSource(self, filename):
@@ -185,6 +203,7 @@ class ProjectWidget(QTabWidget):
 				return -1
 		awlSrcs = self.getAwlSources()
 		symTabSrcs = self.getSymTabSources()
+		libSelections = self.getLibSelections()
 		if not all(awlSrcs) or not all(symTabSrcs):
 			# Failed to generate some sources
 			return 0
@@ -201,6 +220,7 @@ class ProjectWidget(QTabWidget):
 			self.__warnedFileBacked = True
 		self.__project.setAwlSources(awlSrcs)
 		self.__project.setSymTabSources(symTabSrcs)
+		self.__project.setLibSelections(libSelections)
 		self.__project.setProjectFile(filename)
 		self.__project.toFile()
 		if self.__isAdHocProject:
@@ -213,13 +233,67 @@ class ProjectWidget(QTabWidget):
 	def __pasteAwlText(self, text):
 		if self.currentWidget() == self.awlTabs:
 			self.awlTabs.pasteText(text)
+			return True
+		QMessageBox.information(self,
+			"Please select AWL/STL source",
+			"Can not paste template.\n\n"
+			"Please move the text cursor to the place "
+			"in the AWL/STL code where you want to paste "
+			"the template to.")
+		return False
+
+	def __addSymbolToTabWidget(self, tabWidget, symbol):
+		tabWidget.model().beginResetModel()
+		tabWidget.getSymTab().add(symbol)
+		tabWidget.model().revert()
+		tabWidget.model().endResetModel()
+
+	def __pasteSymbol(self, symbolName, address, dataType, comment):
+		# Check if we already have this symbol.
+		for tabWidget in self.symTabs.allTabWidgets():
+			symTable = tabWidget.getSymTab()
+			symbols = tuple(symTable.findByName(symbolName))
+			if symbols:
+				# We already have it.
+				return True
+		# We don't have this symbol, yet. Parse it.
+		try:
+			p = SymTabParser(self.__project.getCpuSpecs().getConfiguredMnemonics())
+			symbol = p.parseSym(symbolName, address,
+					    dataType, comment, 0)
+		except AwlSimError as e:
+			MessageBox.handleAwlSimError(self,
+				"Library symbol error", e)
+			return False
+		assert(self.symTabs.count() >= 1)
+		if self.symTabs.count() == 1:
+			# We only have one table. Add the symbol.
+			self.__addSymbolToTabWidget(self.symTabs.widget(0),
+						    symbol)
 		else:
-			QMessageBox.information(self,
-				"Please select AWL/STL source",
-				"Can not paste template.\n\n"
-				"Please move the text cursor to the place "
-				"in the AWL/STL code where you want to paste "
-				"the template to.")
+			# Ask which table to add the symbol to.
+			tabWidgets = tuple(self.symTabs.allTabWidgets())
+			entries = []
+			for i, tabWidget in enumerate(tabWidgets):
+				entries.append("%d: %s" %\
+					(i + 1, tabWidget.getSource().name))
+			entry, ok = QInputDialog.getItem(self,
+				"Select symbol table",
+				"Please select the symbol table "\
+				"where to add the symbol to:"
+				"\n%s  \"%s\"" %\
+				(address, symbolName),
+				entries, 0, False)
+			if not ok or not entry:
+				return False
+			selIndex = int(entry.split(":")[0]) - 1
+			tabWidget = tabWidgets[selIndex]
+			self.__addSymbolToTabWidget(tabWidget, symbol)
+		return True
+
+	def __pasteLibSel(self, libSelection):
+		self.libTable.addEntry(libSelection)
+		return True
 
 	def insertOB(self):
 		dlg = TemplateDialog("OB", parent=self)
@@ -270,3 +344,21 @@ class ProjectWidget(QTabWidget):
 			self.__pasteAwlText(Templates.getFBcall(dlg.getBlockNumber(),
 								dlg.getExtraNumber(),
 								dlg.getVerbose()))
+
+	def openLibrary(self):
+		dlg = LibraryDialog(self.__project, self)
+		if dlg.exec_() == QDialog.Accepted:
+			if dlg.pasteText:
+				# Paste the code.
+				if not self.__pasteAwlText(dlg.pasteText):
+					return
+			if dlg.pasteSymbol:
+				# Add a symbol to a symbol table.
+				symbolName, address, dataType, comment = dlg.pasteSymbol
+				if not self.__pasteSymbol(symbolName, address,
+							  dataType, comment):
+					return
+			if dlg.pasteLibSel:
+				# Add a library selection to the library table.
+				if not self.__pasteLibSel(dlg.pasteLibSel):
+					return
