@@ -39,6 +39,10 @@ class SymTabModel(QAbstractTableModel):
 		self.__needSourceUpdate = True
 		self.sourceChanged.emit()
 
+	def revert(self):
+		QAbstractTableModel.revert(self)
+		self.__needSourceUpdate = True
+
 	def getSymTab(self):
 		return self.symTab
 
@@ -207,12 +211,17 @@ class SymTabView(QTableView):
 			pass#TODO context menu
 
 	def keyPressEvent(self, ev):
+		QTableView.keyPressEvent(self, ev)
+
 		if ev.key() == Qt.Key_Delete:
 			self.deleteSym()
 
 	def setSymTab(self, symTab):
 		self.setModel(SymTabModel(symTab))
 
+	def getSymTab(self):
+		return self.model().getSymTab()
+
 	def getSource(self):
 		return self.model().getSource()
 
